comments.Mention (Mention) — amici1

# `comments.Mention` (Mention)

Mention(id, modified, created, user, owner_type, owner_id, comment)

Master tables : comments.Mentions (Mentions)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Modified (modified) : The time when this database object was last modified.

- Created (created) : The time when this object was created.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Comment (comment) : See `<django.db.models.fields.related.ForeignKey: comment>`.

- Created (created_natural) : See `lino.modlib.comments.models.Mention.created_natural`.

- Name (name_column) : See `lino.modlib.comments.models.Mention.name_column`.

- (None) (navigation_panel) : See `lino.modlib.comments.models.Mention.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.comments.models.Mention.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
modified | Modified | The time when this database object was last modified.
created | Created | The time when this object was created.
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
comment | Comment |
owner | Controlled by |
created_natural | Created |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |